(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23696,        689]*)
(*NotebookOutlinePosition[     24422,        714]*)
(*  CellTagsIndexPosition[     24378,        710]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Potenzreihen", "Subtitle"],

Cell[TextData[{
  "Version 0.9\n\[Copyright]  2003 by Evelina Erlacher <",
  ButtonBox["evelina.erlacher@gmx.at",
    ButtonData:>{
      URL[ "mailto:evelina.erlacher@gmx.at"], None},
    ButtonStyle->"Hyperlink"],
  ">"
}], "Text"],

Cell["", "Text"],

Cell[TextData[{
  "Die Formel f\[UDoubleDot]r die Taylor-Entwicklung einer Funktion  ",
  StyleBox["f",
    FontSlant->"Italic"],
  "  an der Stelle ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " lautet ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x)\), "=", 
          RowBox[{
            UnderoverscriptBox["\[Sum]", \(k = 0\), "\[Infinity]",
              
              LimitsPositioning->True], \(\(\(f\^\((k)\)\)(
                x\_0)\) \((x - x\_0)\)\^k\/\(k!\)\)}]}], TraditionalForm]]],
  ", wobei ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((k)\)\)(x\_0)\)]],
  " die ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-te Ableitung von  ",
  StyleBox["f",
    FontSlant->"Italic"],
  "  an der Stelle ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_0\)\(\ \)\)\)]],
  "bezeichnet."
}], "Text"],

Cell[TextData[{
  "Wir k\[ODoubleDot]nnen diese Formel verwenden, um z.B. die \
Taylor-Entwicklung der Cosinus-Funktion um 0 bis zum zehnten Glied zu \
berechnen. ",
  StyleBox["D[Cos[x],{x,k}]/.x\[Rule]0",
    FontFamily->"Courier New"],
  " berechnet im Folgenden die ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-te Ableitung der Cosinus-Funktion an der Stelle 0 und ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " ist der Laufindex des ",
  StyleBox["Sum",
    FontFamily->"Courier New"],
  "-Befehls. Der Output ist das zehnte Taylorpolynom der Cosinus-Funktion an \
der Stelle 0."
}], "Text"],

Cell[BoxData[
    \(Sum[\((D[Cos[x], {x, k}] /. x \[Rule] 0)\)*x\^k\/\(k!\), {k, 0, 
        10}]\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " stellt einen Befehl zur Verf\[UDoubleDot]gung, der, wenn die \
Taylor-Formel anwendbar ist, dasselbe Ergebnis mit weniger Aufwand liefert. \
Dieser Befehl hei\[SZ]t ",
  StyleBox["Series",
    FontFamily->"Courier New"],
  " und verlangt zwei Argumente: Als erstes den Funktionsterm der Funktion, \
die in eine Potenzreihe entwickelt werden soll, und als zweites eine Liste, \
die den Namen der Variablen, die Stelle, an der entwickelt werden soll, und \
den Grad, bis zu dem entwickelt werden soll, enth\[ADoubleDot]lt. Der Output \
des Befehls ",
  StyleBox["Series",
    FontFamily->"Courier New"],
  " ist eine Potenzreihe, die in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " durch ein sogenanntes ",
  StyleBox["SeriesData",
    FontFamily->"Courier New"],
  "-Objekt repr\[ADoubleDot]sentiert wird. Ein solches Objekt ist an dem zus\
\[ADoubleDot]tzlichen Term ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            RowBox[{
              StyleBox["O",
                FontSlant->"Plain"], "[", 
              StyleBox["x",
                FontSlant->"Plain"], "]"}], 
            RowBox[{
              StyleBox["n",
                FontSlant->"Plain"], "+", "1"}]],
          FontFamily->"Courier New"], TraditionalForm]]],
  " , der die restlichen Terme der Taylor-Entwicklung \
gr\[ODoubleDot]\[SZ]enordnungsm\[ADoubleDot]\[SZ]ig absch\[ADoubleDot]tzt, \
erkennbar."
}], "Text"],

Cell[TextData[{
  "Hier wird noch einmal die Taylor-Entwicklung der Cosinus-Funktion um 0 bis \
zum zehnten Glied exakt berechnet, diesmal mit dem Befehl ",
  StyleBox["Series",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[
    \(t = Series[Cos[x], {x, 0, 10}]\)], "Input"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"Series", "[", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["(",
                    FontFamily->"Times New Roman"], 
                  StyleBox["x",
                    FontFamily->"Times New Roman",
                    FontSlant->"Italic"], 
                  StyleBox[")",
                    FontFamily->"Times New Roman"]}]}], ",", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times New Roman",
                    FontSlant->"Italic"], ",", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["x",
                        FontSlant->"Italic"], "0"],
                    FontFamily->"Times New Roman"], ",", 
                  StyleBox["n",
                    FontFamily->"Times New Roman",
                    FontSlant->"Italic"]}], "}"}]}], "]"}], 
          RowBox[{
            StyleBox["   ",
              FontFamily->"Times New Roman"], 
            RowBox[{
              RowBox[{
                StyleBox["erzeugt",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["eine",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Potenzreihenentwicklung",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["der",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Funktion",
                  FontFamily->"Times New Roman"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox["f",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox["an",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["der",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Stelle",
                  FontFamily->"Times New Roman"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox[
                  SubscriptBox[
                    StyleBox["x",
                      FontFamily->"Times New Roman",
                      FontSlant->"Italic"], "0"],
                  FontFamily->"Times New Roman"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox["mit",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["bis",
                  FontFamily->"Times New Roman"]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["zum",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Grad",
                  FontFamily->"Times New Roman"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox["n",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                StyleBox["  ",
                  FontFamily->"Times New Roman"], 
                StyleBox["explizit",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["angegebenen",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Termen",
                  FontFamily->"Times New Roman"]}]}]}]}
        },
      ColumnAlignments->{Right, Left}]], "Text",
  CellFrame->True,
  Background->RGBColor[0.679698, 0.890639, 0.996109]],

Cell["\<\
Mit Potenzreihen kann auch gerechnet werden. Das Ergebnis ist (wenn m\
\[ODoubleDot]glich) bis zum selben Grad exakt.\
\>", "Text"],

Cell[BoxData[
    \(t^2\)], "Input"],

Cell[TextData[{
  "Der Befehl ",
  StyleBox["Normal",
    FontFamily->"Courier New"],
  " wandelt eine Potenzreihe in einen normalen Ausdruck um (erkennbar am \
Fehlen des Terms ",
  Cell[BoxData[
      \(O[x]\^\(n + 1\)\)]],
  ")."
}], "Text"],

Cell[BoxData[
    \(Normal[t]\)], "Input"],

Cell["\<\
Wird DIESER Ausdruck quadriert, so erhalten wir ein exaktes Ergebnis.\
\>", "Text"],

Cell[BoxData[
    \(%^2\)], "Input"],

Cell[BoxData[
    \(Clear[t]\)], "Input"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"Normal", "[", 
            StyleBox["potenzreihe",
              FontFamily->"Times New Roman",
              FontSlant->"Italic"], "]"}], 
          RowBox[{"   ", 
            RowBox[{
              RowBox[{
                StyleBox["wandelt",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["die",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Potenzreihe",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["potenzreihe",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                RowBox[{
                  StyleBox["(",
                    FontFamily->"Times New Roman"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["ein",
                        FontFamily->"Times New Roman"], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman"], 
                      StyleBox["SeriesData",
                        FontFamily->"Courier New"]}], 
                    StyleBox["-",
                      FontFamily->"Times New Roman"], 
                    StyleBox["Objekt",
                      FontFamily->"Times New Roman"]}], 
                  StyleBox[")",
                    FontFamily->"Times New Roman"]}], 
                StyleBox["in",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["einen",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["normalen",
                  FontFamily->"Times New Roman"]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], "\[IndentingNewLine]", 
              StyleBox[\(Ausdruck\ um\),
                FontFamily->"Times New Roman"]}]}]}
        },
      ColumnAlignments->{Right, Left}]], "Text",
  CellFrame->True,
  Background->RGBColor[0.679698, 0.890639, 0.996109]],

Cell["Hier sind zwei Potenzreihen.", "Text"],

Cell[BoxData[{
    \(s = Series[Exp[x], {x, 0, 7}]\), "\[IndentingNewLine]", 
    \(t = Series[Tan[x], {x, 0, 7}]\)}], "Input"],

Cell["\<\
Um zwei Potenzreihen zusammenzusetzen, kann man entweder die eine direkt in \
die andere einsetzen...\
\>", "Text"],

Cell[BoxData[
    \(s /. x \[Rule] t\)], "Input"],

Cell[TextData[{
  "...oder den eingebauten Befehl ",
  StyleBox["ComposeSeries",
    FontFamily->"Courier New"],
  " verwenden."
}], "Text"],

Cell[BoxData[
    \(ComposeSeries[s, t]\)], "Input"],

Cell[BoxData[
    \(Clear[s, t]\)], "Input"],

Cell["Hier ist die Potenzreihenentwicklung der Sinus-Funktion.", "Text"],

Cell[BoxData[
    \(r = Series[Sin[x], {x, 0, 10}]\)], "Input"],

Cell[TextData[{
  "Der Befehl ",
  StyleBox["InverseSeries",
    FontFamily->"Courier New"],
  " gibt die Potenzreihenentwicklung der inversen Funktion, hier also ",
  Cell[BoxData[
      \(TraditionalForm\`sin\^\(-1\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(InverseSeries[r, y]\)], "Input"],

Cell["\<\
Die Zusammensetzung der Potenzreihe einer Funktion und die der inversen \
Funktion gibt die Identit\[ADoubleDot]t (bzw. die Potenzreihenentwicklung der \
Identit\[ADoubleDot]t).\
\>", "Text"],

Cell[BoxData[
    \(% /. y \[Rule] r\)], "Input"],

Cell[TextData[{
  "Mit dem Befehl ",
  StyleBox["SeriesCoefficient",
    FontFamily->"Courier New"],
  " l\[ADoubleDot]sst sich der Koeffizient des Terms vom Grad ",
  StyleBox["n",
    FontSlant->"Italic"],
  " aus der Taylor-Entwicklung herausgreifen."
}], "Text"],

Cell[BoxData[
    \(SeriesCoefficient[r, 7]\)], "Input"],

Cell[BoxData[
    \(Clear[r]\)], "Input"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"ComposeSeries", "[", 
            RowBox[{
              StyleBox[
                SubscriptBox["reihe", 
                  StyleBox["1",
                    FontSlant->"Plain"]],
                FontFamily->"Times New Roman",
                FontSlant->"Italic"], ",", 
              StyleBox[
                SubscriptBox["reihe", 
                  StyleBox["2",
                    FontSlant->"Plain"]],
                FontFamily->"Times New Roman",
                FontSlant->"Italic"]}], "]"}], 
          RowBox[{"   ", 
            StyleBox[
              RowBox[{
              "ersetzt", " ", "die", " ", "Variable", " ", "in", " ", "der", 
                " ", "Potenzreihe", " ", 
                SubscriptBox[
                  StyleBox["reihe",
                    FontFamily->"Times New Roman",
                    FontSlant->"Italic"], "1"], " ", "durch", " ", "die", " ",
                 "Potenzreihe", " ", 
                SubscriptBox[
                  StyleBox["reihe",
                    FontFamily->"Times New Roman",
                    FontSlant->"Italic"], "2"]}],
              FontFamily->"Times New Roman"]}]},
        {
          RowBox[{"InverseSeries", "[", 
            RowBox[{
              StyleBox["reihe",
                FontFamily->"Times New Roman",
                FontSlant->"Italic"], ",", 
              StyleBox["x",
                FontFamily->"Times New Roman",
                FontSlant->"Italic"]}], "]"}], 
          RowBox[{"   ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["liefert",
                    FontFamily->"Times New Roman"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], 
                  StyleBox["die",
                    FontFamily->"Times New Roman"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], 
                  StyleBox["Potenzreihenentwicklung",
                    FontFamily->"Times New Roman"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], 
                  RowBox[{
                    StyleBox["(",
                      FontFamily->"Times New Roman"], 
                    RowBox[{
                      StyleBox["in",
                        FontFamily->"Times New Roman"], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman"], 
                      StyleBox["der",
                        FontFamily->"Times New Roman"], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman"], 
                      StyleBox["Variablen",
                        FontFamily->"Times New Roman"], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman"], 
                      StyleBox["x",
                        FontFamily->"Times New Roman",
                        FontSlant->"Italic"]}], 
                    StyleBox[")",
                      FontFamily->"Times New Roman"]}], 
                  StyleBox["der",
                    FontFamily->"Times New Roman"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], 
                  StyleBox["Funktion",
                    FontFamily->"Times New Roman"]}], 
                StyleBox[",",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["die",
                  FontFamily->"Times New Roman"]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["invers",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["zu",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["der",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["durch",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["die",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Potenzreihe",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["reihe",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["dargestellten",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Funktion",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["ist",
                  FontFamily->"Times New Roman"]}]}]}]},
        {
          RowBox[{"SeriesCoefficient", "[", 
            RowBox[{
              StyleBox["reihe",
                FontFamily->"Times New Roman",
                FontSlant->"Italic"], ",", 
              StyleBox["n",
                FontFamily->"Times New Roman",
                FontSlant->"Italic"]}], "]"}], 
          RowBox[{"   ", 
            RowBox[{
              RowBox[{
                StyleBox["liefert",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["den",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Koeffizienten",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["des",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Terms",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["vom",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Grad",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["n",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["der",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["Taylor",
                  FontFamily->"Times New Roman"]}], 
              StyleBox["-",
                FontFamily->"Times New Roman"], 
              RowBox[{
                StyleBox["Reihe",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["reihe",
                  FontFamily->"Times New Roman",
                  FontSlant->"Italic"]}]}]}]}
        },
      ColumnAlignments->{Right, Left}]], "Text",
  CellFrame->True,
  Background->RGBColor[0.679698, 0.890639, 0.996109]],

Cell["\<\
Je h\[ODoubleDot]her der Grad des Taylorpolynoms ist, desto besser \
approximiert es die Funktion.\
\>", "Text"],

Cell[TextData[{
  "Hier ist die Liste der Taylorpolynome vom Grad 2, 6, 10, 14, 18 und 22 der \
Funktion sin(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ") an der Stelle 0."
}], "Text"],

Cell[BoxData[
    \(Table[Normal[Series[Sin[x^2], {x, 0, k}]], {k, 2, 22, 4}]\)], "Input"],

Cell["Wir f\[UDoubleDot]gen der Liste auch noch die Funktion selbst hinzu.", \
"Text"],

Cell[BoxData[
    \(Join[%, {Sin[x^2]}]\)], "Input"],

Cell[TextData[{
  "Nun plotten wir die Taylorpolynome und die Funktion sin(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "). Je h\[ODoubleDot]her der Grad des Taylorpolynoms, desto dunkler ist der \
Graph. Der ",
  "Graph",
  " von sin(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ") ist schwarz."
}], "Text"],

Cell[BoxData[
    \(Plot[Evaluate[%], {x, 0, 3}, 
      PlotStyle \[Rule] 
        Table[{GrayLevel[i]}, {i, 7/8, 0, \(-1\)/8}]]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 680}},
WindowToolbars->{},
WindowSize->{1016, 648},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 32, 0, 64, "Subtitle"],
Cell[1762, 54, 233, 7, 52, "Text"],
Cell[1998, 63, 16, 0, 33, "Text"],
Cell[2017, 65, 833, 29, 44, "Text"],
Cell[2853, 96, 608, 17, 52, "Text"],
Cell[3464, 115, 110, 2, 45, "Input"],
Cell[3577, 119, 1509, 39, 90, "Text"],
Cell[5089, 160, 227, 6, 33, "Text"],
Cell[5319, 168, 63, 1, 30, "Input"],
Cell[5385, 171, 4579, 114, 67, "Text"],
Cell[9967, 287, 141, 3, 33, "Text"],
Cell[10111, 292, 36, 1, 30, "Input"],
Cell[10150, 295, 244, 9, 33, "Text"],
Cell[10397, 306, 42, 1, 30, "Input"],
Cell[10442, 309, 93, 2, 33, "Text"],
Cell[10538, 313, 36, 1, 30, "Input"],
Cell[10577, 316, 41, 1, 30, "Input"],
Cell[10621, 319, 2447, 60, 67, "Text"],
Cell[13071, 381, 44, 0, 33, "Text"],
Cell[13118, 383, 127, 2, 50, "Input"],
Cell[13248, 387, 125, 3, 33, "Text"],
Cell[13376, 392, 49, 1, 30, "Input"],
Cell[13428, 395, 140, 5, 33, "Text"],
Cell[13571, 402, 52, 1, 30, "Input"],
Cell[13626, 405, 44, 1, 30, "Input"],
Cell[13673, 408, 72, 0, 33, "Text"],
Cell[13748, 410, 63, 1, 30, "Input"],
Cell[13814, 413, 241, 8, 33, "Text"],
Cell[14058, 423, 52, 1, 30, "Input"],
Cell[14113, 426, 201, 4, 33, "Text"],
Cell[14317, 432, 49, 1, 30, "Input"],
Cell[14369, 435, 266, 8, 33, "Text"],
Cell[14638, 445, 56, 1, 30, "Input"],
Cell[14697, 448, 41, 1, 30, "Input"],
Cell[14741, 451, 7900, 195, 103, "Text"],
Cell[22644, 648, 122, 3, 33, "Text"],
Cell[22769, 653, 197, 6, 33, "Text"],
Cell[22969, 661, 90, 1, 30, "Input"],
Cell[23062, 664, 86, 1, 33, "Text"],
Cell[23151, 667, 52, 1, 30, "Input"],
Cell[23206, 670, 330, 11, 33, "Text"],
Cell[23539, 683, 141, 3, 30, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

